@@ -303,9 +303,7 @@ static const char *BUCKET_OP[] = { "PUSH", "PULL" };
  */
 typedef struct {
     char *data_hash;
-    char *reporter_id;
-    char *farmer_id;
-    char *client_id;
+    char *token;
     uint64_t start;
     uint64_t end;
     unsigned int code;
